==> ServiceDesk-0.3.zip: ServiceDesk/function.admin_optionstab.php <==
<?php
# ServiceDesk (Service desk to support incidents and requests). A module for CMS - CMS Made Simple
# Copyright (c) 2009 by Duketown
#
# This function supports the back end for the module servicedesk
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/servicedesk
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

// Prepare list of possible statusses to select from
$statuslist = array();
$statuslist = $this->GetListStatusses();

// Prepare a list of internal users (one of which will be the default owner of incidents)
$ownerlist = array();
$ownerlist = $this->GetListOwners();

// Prepare the list of page names
$contentlist = array();
$contentlist = $this->GetListContent();

// Prepare a list of templates for front end submition
$fetemplatelist = array();
$fetemplatelist = $this->GetListFETemplates();

$this->smarty->assign('startform', $this->CreateFormStart ($id, 'save_admin_options', $returnid));
$this->smarty->assign('defaultstatustext',$this->Lang('title_default_status'));
$this->smarty->assign('defaultstatusinput', $this->CreateInputDropdown($id, 'defaultstatus', $statuslist, -1, 
	$this->GetPreference('defaultstatus', 'OP'), 'class="defaultfocus"'));
$this->smarty->assign('defaultownertext',$this->Lang('title_default_owner'));
$this->smarty->assign('defaultownerinput', $this->CreateInputDropdown($id, 'defaultowner', $ownerlist, -1, 
	$this->GetPreference('defaultowner', -1)));
$this->smarty->assign('enableeditortext',$this->Lang('title_enableeditor'));
$this->smarty->assign('enableeditorinput', $this->CreateInputCheckbox($id, 
	'enableeditor', true, $this->GetPreference('enableeditor', true)));
$this->smarty->assign('fesubmitredirecttext',$this->Lang('title_fesubmit_redirect'));
$this->smarty->assign('fesubmitredirectinput', $this->CreateInputDropdown($id, 'fesubmit_redirect', 
	$contentlist, -1, $this->GetPreference('fesubmit_redirect', 'home')));
$this->smarty->assign('defaultfetemplatetext',$this->Lang('title_default_fetemplate'));
$this->smarty->assign('defaultfetemplateinput', $this->CreateInputDropdown($id, 'current_form_template', 
	$fetemplatelist, -1, $this->GetPreference('current_form_template', -1)));
$this->smarty->assign('allowchangerequestortext',$this->Lang('title_allowchangerequestor'));
$this->smarty->assign('allowchangerequestorinput', $this->CreateInputCheckbox($id, 
	'allowchangerequestor', true, $this->GetPreference('allowchangerequestor', true)));
$this->smarty->assign('enablemailwysiwygtext',$this->Lang('title_enablemailwysiwyg'));
$this->smarty->assign('enablemailwysiwyginput', $this->CreateInputCheckbox($id, 
	'enablemailwysiwyg', true, $this->GetPreference('enablemailwysiwyg', true)));

$this->smarty->assign('submit', $this->CreateInputSubmit ($id, 'optionssubmitbutton', $this->Lang('submit')));
$this->smarty->assign('endform', $this->CreateFormEnd ());

// Display the options
echo $this->ProcessTemplate('listoptions.tpl');

?>

==> ServiceDesk-0.8.zip: ServiceDesk/function.admin_optionstab.php <==
<?php
# ServiceDesk (Service desk to support incidents and requests). A module for CMS - CMS Made Simple
# Copyright (c) 2009 by Duketown
#
# This function supports the back end for the module servicedesk
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/servicedesk
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

// Prepare list of possible statusses to select from
$statuslist = array();
$statuslist = $this->GetListStatusses();

// Prepare a list of internal users (one of which will be the default owner of incidents)
$ownerlist = array();
$ownerlist = sdbe_utils::GetListOwners();

// Prepare the list of page names
$contentlist = array();
$contentlist = $this->GetListContent();

// Prepare a list of templates for front end submition
$fetemplatelist = array();
$fetemplatelist = $this->GetListFETemplates();

$this->smarty->assign('startform', $this->CreateFormStart ($id, 'save_admin_options', $returnid));
$this->smarty->assign('defaultstatustext',$this->Lang('title_default_status'));
$this->smarty->assign('defaultstatusinput', $this->CreateInputDropdown($id, 'defaultstatus', $statuslist, -1, 
	$this->GetPreference('defaultstatus', 'OP'), 'class="defaultfocus"'));
$this->smarty->assign('defaultownertext',$this->Lang('title_default_owner'));
$this->smarty->assign('defaultownerinput', $this->CreateInputDropdown($id, 'defaultowner', $ownerlist, -1, 
	$this->GetPreference('defaultowner', -1)));
$this->smarty->assign('enableeditortext',$this->Lang('title_enableeditor'));
$this->smarty->assign('enableeditorinput', $this->CreateInputCheckbox($id, 
	'enableeditor', true, $this->GetPreference('enableeditor', 1)));
$this->smarty->assign('fesubmitredirecttext',$this->Lang('title_fesubmit_redirect'));
$this->smarty->assign('fesubmitredirectinput', $this->CreateInputDropdown($id, 'fesubmit_redirect', 
	$contentlist, -1, $this->GetPreference('fesubmit_redirect', 'home')));
$this->smarty->assign('defaultfetemplatetext',$this->Lang('title_default_fetemplate'));
$this->smarty->assign('defaultfetemplateinput', $this->CreateInputDropdown($id, 'current_form_template', 
	$fetemplatelist, -1, $this->GetPreference('current_form_template', -1)));
$this->smarty->assign('allowchangerequestortext',$this->Lang('title_allowchangerequestor'));
$this->smarty->assign('allowchangerequestorinput', $this->CreateInputCheckbox($id, 
	'allowchangerequestor', true, $this->GetPreference('allowchangerequestor', 1)));
$this->smarty->assign('enablemailwysiwygtext',$this->Lang('title_enablemailwysiwyg'));
$this->smarty->assign('enablemailwysiwyginput', $this->CreateInputCheckbox($id, 
	'enablemailwysiwyg', true, $this->GetPreference('enablemailwysiwyg', 1)));

$this->smarty->assign('submit', $this->CreateInputSubmit ($id, 'optionssubmitbutton', $this->Lang('submit')));
$this->smarty->assign('endform', $this->CreateFormEnd ());

// Display the options
echo $this->ProcessTemplate('listoptions.tpl');

?>
